@@ -424,7 +424,11 @@ stop = function(msg) {
 "$<-.GlobalOptionsFun" = function(x, nm, value) {
 	lt = list()
 	lt[[nm]] = value
-	do.call("x", lt)
-	x
+
+	assign(".__temp_opt__.", x, envir = parent.frame())
+	do.call(".__temp_opt__.", lt, envir = parent.frame())
+	rm(".__temp_opt__.", envir = parent.frame())
+
+	return(x)
 }
 
